==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/user/messages/sv/base.php <==
<?php

return [
    '<strong>Followers</strong>' => '<strong>Användarens</strong> följare',
    '<strong>Following</strong>' => '<strong>Följer</strong> användare',
    '<strong>Group</strong> members - {group}' => '<strong>Grupp</strong> medlemmar - {group}',
    '<strong>Member</strong> in these spaces' => '<strong>Medlem</strong> i dessa forum',
    '<strong>Member</strong> of these Spaces' => '<strong>Medlem</strong> av dessa forum',
    '<strong>People</strong>' => '<strong>Personer</strong>',
    '<strong>User</strong> tags' => '<strong>Användar</strong> taggar',
    'All' => 'Alla',
    'Allows access to your about page with personal information' => 'Tillåter åtkomst till ”Min profil” med personlig information',
    'Any' => 'Några',
    'Auth Mode' => 'Auth läge',
    'Basic Settings' => 'Grundinställningar',
    'Change Email' => 'Byt e-post',
    'Change Password' => 'Byt lösenord',
    'Change Username' => 'Byt användarnamn',
    'Confirm new password' => 'Bekräfta lösenord',
    'Connect account' => 'Skapa konto',
    'Connected Accounts' => 'Anslutna konton',
    'Connected accounts' => 'Anslutna konton',
    'Created at' => 'Skapad',
    'Created by' => 'Skapad av',
    'Current password' => 'Nuvarande lösenord',
    'Currently in use' => 'Används redan',
    'Default Group' => 'Förvald grupp',
    'Default Space' => 'Förvalt forum',
    'Delete' => 'Radera',
    'Delete Account' => 'Radera konto',
    'Description' => 'Beskrivning',
    'Disconnect account' => 'Avsluta konto',
    'E-Mail is already in use! - Try forgot password.' => 'E-postadressen används redan! - Prova glömt lösenord.',
    'Email' => 'E-post',
    'Enable Notifications' => 'Aktivera notifieringar',
    'Find people by their profile data or user tags' => 'Hitta personer genom deras profildata eller användartaggar',
    'Follow' => 'Följ',
    'Followers' => 'Följare',
    'Following' => 'Följer',
    'Force password change upon first login' => 'Tvinga uppdatering av lösenord vid första inloggning',
    'Force password change upon next login' => 'Tvinga uppdatering av lösenord vid nästa inloggning',
    'Friends' => 'Vänner',
    'General' => 'Allmän',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Här kan du koppla mot externa tjänster som single sign on autentisering.',
    'Language' => 'Språk',
    'Last Login' => 'Senaste Inloggningen',
    'Manager' => 'Administratör',
    'Missing E-Mail Attribute from AuthClient.' => 'Saknar e-postattribut från AuthClient',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Saknar ID AuthClient attribut från ID AuthClient.',
    'Modules' => 'Moduler',
    'My Account' => 'Mitt konto',
    'Name' => 'Namn',
    'New password' => 'Nytt lösenord',
    'No results found!' => 'Inga resultat funna!',
    'No users found.' => 'Inga användare funna',
    'Notifications' => 'Notiser',
    'Password' => 'Lösenord',
    'Password changed' => 'Lösenordet ändrat',
    'Password needs to be at least {chars} characters long.' => 'Lösenordet måste vara minst {chars} tecken långt.',
    'Pending Requests' => 'Väntande förfrågningar',
    'People' => 'Personer',
    'Permission' => 'Rättigheter',
    'Profile' => 'Profil',
    'Profile posts only' => 'Endast inlägg på profilen',
    'Register now and participate!' => 'Registrera dig och delta!',
    'Search...' => 'Sök...',
    'Security' => 'Säkerhet',
    'Send invite' => 'Skicka inbjudan',
    'Settings' => 'Inställningar',
    'Show At Registration' => 'Visa vid registret',
    'Show all content' => 'Visa allt innehåll',
    'Sign in' => 'Logga in',
    'Sign in / up' => 'Logga in / Bli medlem',
    'Sign up' => 'Bli medlem',
    'Sign up now' => 'Gå med nu',
    'Sort order' => 'Sorteringsordning',
    'Source' => 'Källa',
    'Status' => 'Status',
    'Tags' => 'Taggar',
    'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
    'Unknown user status!' => 'Okänd användarstatus',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Misslyckade inloggningsförsök sedan senaste inloggning: {failedLoginAttemptsCount}',
    'Updated at' => 'Uppdaterad',
    'Updated by' => 'Uppdaterad av',
    'User' => 'Användare',
    'User Group' => 'Användargrupp',
    'User has been invited.' => 'Användare har blivit inbjuden.',
    'Username' => 'Användarnamn',
    'Username contains invalid characters.' => 'Användarnamnet innehåller ogiltiga tecken.',
    'View your about page' => 'Visa din profilsida',
    'Visibility' => 'Synlighet',
    'Visible' => 'Synlig',
    'Welcome to %appName%' => 'Välkommen till %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Välkommen till %appName%.. Klicka på knappen nedan för att gå vidare med din registrering.',
    'You got an invite' => 'Du har fått en inbjudan',
    'You\'re not registered.' => 'Du är inte registrerad',
    'You\'ve been invited to join {space} on {appName}' => 'Du har blivit inbjuden att gå med i {space} på {appName}',
    'Your account is disabled!' => 'Ditt konto är inaktiverat!',
    'Your account is not approved yet!' => 'Ditt konto är inte godkänt än!',
    'Your are already logged in! - Logout first!' => 'Du är redan inloggad! - Logga ut först!',
    'Your new password must not be equal your current password!' => 'Ditt nya lösenord kan inte vara samma som ditt nuvarande lösenord!',
    'invited you to join {name}.' => 'bjöd in dig att delta {name}',
    'invited you to join {space} on {name}.' => 'bjöd in dig att gå med i {space} på {name}.',
    'or' => 'eller',
    'Allow users to mention you' => '',
    'Invited by' => '',
    'Mentioning' => '',
];

==> humhub-1.17.0-beta.2.tar.gz: humhub-1.17.0-beta.2/protected/humhub/modules/user/messages/sv/base.php <==
<?php

return [
    '<strong>Followers</strong>' => '<strong>Användarens</strong> följare',
    '<strong>Following</strong>' => '<strong>Följer</strong> användare',
    '<strong>Member</strong> in these spaces' => '<strong>Medlem</strong> i dessa forum',
    '<strong>Member</strong> of these Spaces' => '<strong>Medlem</strong> av dessa forum',
    '<strong>People</strong>' => '<strong>Personer</strong>',
    '<strong>User</strong> tags' => '<strong>Användar</strong> taggar',
    'All' => 'Alla',
    'Allow users to mention you' => 'Tillåt användare att omnämna dig',
    'Allows access to your about page with personal information' => 'Tillåter åtkomst till ”Min profil” med personlig information',
    'Any' => 'Några',
    'Auth Mode' => 'Auth läge',
    'Basic Settings' => 'Grundinställningar',
    'Change Email' => 'Byt e-post',
    'Change Password' => 'Byt lösenord',
    'Change Username' => 'Byt användarnamn',
    'Confirm new password' => 'Bekräfta lösenord',
    'Connect account' => 'Skapa konto',
    'Connected Accounts' => 'Anslutna konton',
    'Connected accounts' => 'Anslutna konton',
    'Created at' => 'Skapad',
    'Created by' => 'Skapad av',
    'Current password' => 'Nuvarande lösenord',
    'Currently in use' => 'Används redan',
    'Default Group' => 'Förvald grupp',
    'Default Space' => 'Förvalt forum',
    'Delete' => 'Radera',
    'Delete Account' => 'Radera konto',
    'Description' => 'Beskrivning',
    'Did you forget your password?' => 'Glömde du ditt lösenord?',
    'Disconnect account' => 'Avsluta konto',
    'Edit' => 'Ändra',
    'Email' => 'E-post',
    'Enable Notifications' => 'Aktivera notifieringar',
    'Find people by their profile data or user tags' => 'Hitta personer genom deras profildata eller användartaggar',
    'Follow' => 'Följ',
    'Followers' => 'Följare',
    'Following' => 'Följer',
    'Following (User)' => 'Följer (användare)',
    'Force password change upon first login' => 'Tvinga uppdatering av lösenord vid första inloggning',
    'Force password change upon next login' => 'Tvinga uppdatering av lösenord vid nästa inloggning',
    'Friends' => 'Vänner',
    'Here you can connect to external service provider for using external services like a single sign on authentication.' => 'Här kan du koppla mot externa tjänster som single sign on autentisering.',
    'If this wasn\'t you, you can disregard this message.' => 'Om det här inte var du kan du bortse från det här meddelandet.',
    'Invite by email' => 'Inbjudan via e-post',
    'Invite by link' => 'Bjud in via länk',
    'Invite new people' => 'Bjud in nya personer',
    'Invited by' => 'Inbjuden av',
    'It looks like you clicked on an invalid password reset link. Please try again.' => 'Det verkar som att du klickade på en ogiltig länk för återställning av lösenord. Var god försök igen.',
    'Language' => 'Språk',
    'Last Login' => 'Senaste Inloggningen',
    'Mentioning' => 'Omnämnande',
    'Missing E-Mail Attribute from AuthClient.' => 'Saknar e-postattribut från AuthClient',
    'Missing ID AuthClient Attribute from AuthClient.' => 'Saknar ID AuthClient attribut från ID AuthClient.',
    'Modules' => 'Moduler',
    'My Account' => 'Mitt konto',
    'Name' => 'Namn',
    'New password' => 'Nytt lösenord',
    'No results found!' => 'Inga resultat funna!',
    'No users found.' => 'Inga användare funna',
    'Notifications' => 'Notiser',
    'Offline' => 'Offline',
    'Online' => 'Online',
    'Password' => 'Lösenord',
    'Password changed' => 'Lösenordet ändrat',
    'Password needs to be at least {chars} characters long.' => 'Lösenordet måste vara minst {chars} tecken långt.',
    'Password recovery' => 'Lösenordsåterställning',
    'Pending Requests' => 'Väntande förfrågningar',
    'People' => 'Personer',
    'Permission' => 'Rättigheter',
    'Profile' => 'Profil',
    'Profile posts only' => 'Endast inlägg på profilen',
    'Register now and participate!' => 'Registrera dig och delta!',
    'Search...' => 'Sök...',
    'Security' => 'Säkerhet',
    'Settings' => 'Inställningar',
    'Show At Registration' => 'Visa vid registret',
    'Show all content' => 'Visa allt innehåll',
    'Sign in' => 'Logga in',
    'Sign in / up' => 'Logga in / Bli medlem',
    'Sign up' => 'Bli medlem',
    'Sign up now' => 'Gå med nu',
    'Sort order' => 'Sorteringsordning',
    'Source' => 'Källa',
    'Status' => 'Status',
    'Tags' => 'Taggar',
    'The secure link has been copied in your clipboard!' => 'Den säkra länken har kopierats till ditt urklipp!',
    'Try other keywords or remove filters.' => 'Prova andra sökord eller ta bort filter.',
    'Unknown user status!' => 'Okänd användarstatus',
    'Unsuccessful login attempts since last login: {failedLoginAttemptsCount}' => 'Misslyckade inloggningsförsök sedan senaste inloggning: {failedLoginAttemptsCount}',
    'Updated at' => 'Uppdaterad',
    'Updated by' => 'Uppdaterad av',
    'User' => 'Användare',
    'User Group' => 'Användargrupp',
    'User has been invited.' => 'Användare har blivit inbjuden.',
    'Username' => 'Användarnamn',
    'Username contains invalid characters.' => 'Användarnamnet innehåller ogiltiga tecken.',
    'View your about page' => 'Visa din profilsida',
    'Visibility' => 'Synlighet',
    'Visible' => 'Synlig',
    'Welcome to %appName%' => 'Välkommen till %appName%',
    'Welcome to %appName%. Please click on the button below to proceed with your registration.' => 'Välkommen till %appName%.. Klicka på knappen nedan för att gå vidare med din registrering.',
    'Whenever a user follows another user.' => 'Närhelst en användare följer en annan användare.',
    'You got an invite' => 'Du har fått en inbjudan',
    'You tried registering an account with %appName%, but already have an account associated with this email address.' => 'Du försökte registrera ett konto med %appName%, men har redan ett konto kopplat till den här e-postadressen.',
    'You\'re not registered.' => 'Du är inte registrerad',
    'You\'ve been invited to join {space} on {appName}' => 'Du har blivit inbjuden att gå med i {space} på {appName}',
    'Your account is disabled!' => 'Ditt konto är inaktiverat!',
    'Your account is not approved yet!' => 'Ditt konto är inte godkänt än!',
    'Your are already logged in! - Logout first!' => 'Du är redan inloggad! - Logga ut först!',
    'Your new password must not be equal your current password!' => 'Ditt nya lösenord kan inte vara samma som ditt nuvarande lösenord!',
    'invited you to join {name}.' => 'bjöd in dig att delta {name}',
    'invited you to join {space} on {name}.' => 'bjöd in dig att gå med i {space} på {name}.',
    'or' => 'eller',
    'Advanced Profile Search' => '',
    'Block user' => '',
    'Empty password cannot be saved!' => '',
    'Group Manager(s)' => '',
    'The Group Manager can approve pending registrations of this group.' => '',
    'The user has been blocked for you.' => '',
    'The user has been unblocked for you.' => '',
    'Unblock user' => '',
];
